pub struct Scheduler { /* private fields */ }Implementations
Sourceimpl Scheduler
impl Scheduler
Sourcepub fn with_timezone(timezone_hours: i8, timezone_minutes: i8) -> Self
pub fn with_timezone(timezone_hours: i8, timezone_minutes: i8) -> Self
create a new scheduler with specified timezone hours offset
Sourcepub fn with_timezone_minutes(timezone_minutes: i16) -> Self
pub fn with_timezone_minutes(timezone_minutes: i16) -> Self
create a new scheduler with timezone offset in minutes
Sourcepub async fn run<T: Notifiable + 'static>(&self, task: T)
pub async fn run<T: Notifiable + 'static>(&self, task: T)
run the task
Sourcepub fn get_cancel(&self) -> CancellationToken
pub fn get_cancel(&self) -> CancellationToken
get the cancel token